@@ -28,8 +28,8 @@ qx.Class.define("callbackery.ui.Screen", {
                 this.addListenerOnce('appear',this.instanciatePlugin,this);
                 break;
             default:
-                console.log('ERROR unknown instanciationMode '+cfg.instanciationMode)
-        });
+                console.log('ERROR unknown instanciationMode '+cfg.instanciationMode);
+        };
     },
 
     events: {
@@ -58,7 +58,7 @@ qx.Class.define("callbackery.ui.Screen", {
                         that.fireDataEvent('actionResponse',e.getData());
                     });
                     // track visibility changes in the screen widget
-                    content.addListener('changeVisiblity',function(){
+                    content.addListener('changeVisibility',function(){
                         this.setVisibility(content.getVisibility());
                     },that);
                     that.add(content);
